//*************************************************************************
//インクルードファイル    1lcd_lib_XC32.h
//このファイルは後閑哲也さんが設計されたCCSコンパイラ用液晶表示ライブラリ　
//1lcd_lib.cをもとに、XC32コンパイラ対応等で変更したものです。
//*************************************************************************
#include <p32xxxx.h>

#define lcd_Clock   200000000        //システムクロック     //単位はHzで指定


// LCDポート設定
#define	lcd_port_DB7	LATAbits.LATA1	//LCDのDB7（14番ピン)に接続されるPIC側ポート番号設定
#define	lcd_port_DB6	LATBbits.LATB11	//LCDのDB6(13番ピン)に接続されるPIC側ポート番号設定
#define	lcd_port_DB5	LATAbits.LATA10	//LCDのDB5(12番ピン)に接続されるPIC側ポート番号設定
#define	lcd_port_DB4	LATAbits.LATA9	//LCDのDB4（11番ピン)に接続されつPIC側ポート番号設定
#define	lcd_rs		LATBbits.LATB6	//LCDのrs（4番ピン)に接続されるPIC側ポート番号設定
#define	lcd_stb		LATBbits.LATB7	//LCDのstb（6番ピン)に接続されるPIC側ポート番号設定


//LCDポート: 出力モード設定
#define lcd_port_DB7_ConfigOut()   TRISAbits.TRISA1 = 0
#define lcd_port_DB6_ConfigOut()   TRISBbits.TRISB11 = 0
#define lcd_port_DB5_ConfigOut()   TRISAbits.TRISA10 = 0
#define lcd_port_DB4_ConfigOut()   TRISAbits.TRISA9 = 0
#define lcd_rs_ConfigOut()     TRISBbits.TRISB6 = 0
#define lcd_stb_ConfigOut()    TRISBbits.TRISB7 = 0


//LCDポート: デジタルモード設定
#define lcd_port_DB7_ConfigDigital()   ANSELAbits.ANSA1 = 0
#define lcd_port_DB6_ConfigDigital()   ANSELBbits.ANSB11 = 0
#define lcd_port_DB5_ConfigDigital()   ANSELAbits.ANSA10 = 0
#define lcd_port_DB4_ConfigDigital()   ANSELAbits.ANSA9 = 0
#define lcd_rs_ConfigDigital()   ANSELBbits.ANSB6 = 0
#define lcd_stb_ConfigDigital()   ANSELBbits.ANSB7 = 0



void lcd_out(volatile char code, volatile char flag);
void lcd_data(volatile char asci);
void lcd_cmd(volatile char cmd);
void lcd_clear(void);
void lcd_init(void);
void lcd_str(char *str);



